@@ -15,20 +15,24 @@ import random
 import sys
 import time
 
-
-#: The version of this script
-__version__ = '0.3.0'
+from leekspin import __version__
+from leekspin import __package__
 
 
 def getArgParser():
     """Get our :class:`~argparse.ArgumentParser`."""
-    parser = argparse.ArgumentParser(add_help=True)
-    parser.version = __version__
+    version_ = '-'.join([__package__, __version__.rsplit('_', 1)[0]])
+    parser = argparse.ArgumentParser(prog=__package__,
+                                     add_help=True)
+    # Otherwise we hit an argparse bug that prints the following cryptic error:
+    # `'Namespace' object has no 'version' attribute`
+    parser.prog = __package__
+    parser.version = version_
     parser.description  = "Generate a signed set of network-status, "
     parser.description += "extra-info, and server descriptor documents "
     parser.description += "for mock Tor relays or bridges."
-    infoargs = parser.add_mutually_exclusive_group()
     verbargs = parser.add_mutually_exclusive_group()
+    infoargs = parser.add_mutually_exclusive_group()
     infoargs.add_argument("-v", "--verbose", action="store_true",
                           help="print information to stdout")
     infoargs.add_argument("-q", "--quiet", action="store_true",
@@ -40,6 +44,11 @@ def getArgParser():
     group.title = "required arguments"
     group.add_argument("-n", "--descriptors", default=0,
                        help="generate <n> descriptor sets", type=int)
+
+    parser.add_argument("-r", "--relay", action="store_true",
+                        help=("generate relay descriptors (without this\n"
+                              "flag, bridge descriptor will be created)"))
+
     return parser
 
 def randomIP():
@@ -57,8 +66,16 @@ def randomIPv6():
     return ipaddr.IPv6Address(random.getrandbits(128))
 
 def randomPort():
-    """Get a random integer in the range [1024, 65535]."""
-    return random.randint(1025, 65535)
+    """Get a random integer in the range [1026, 65530].
+
+    The reason that port 1025 is missing is because the IPv6 port (in the
+    ``or-address``/``a`` lines), if there will be one, will be whatever the
+    random ORPort is, minus one.
+
+    The pluggable transport in the extrainfo descriptor (if there are any) are
+    calculated as the random ORPort, plus some.
+    """
+    return random.randint(1026, 65530)
 
 def getHexString(size):
     """Get a capitalised hexidecimal string ``size`` bytes long.
